@@ -1,13 +1,10 @@
 import os
-import aiohttp
 import asyncio
 
 from asynctest import TestCase
 from barterdude import BarterDude
 from barterdude.monitor import Monitor
-from barterdude.hooks.healthcheck import Healthcheck
 from barterdude.hooks.logging import Logging
-from barterdude.hooks.metrics.prometheus import Prometheus
 from barterdude.message import ValidationException
 from tests_unit.helpers import load_fixture
 from tests_integration.helpers import ErrorHook
@@ -296,133 +293,6 @@ class RabbitMQConsumerTest(TestCase):
 
         self.assertSetEqual(second_read, {self.messages[0]["key"]})
 
-    async def test_obtains_healthcheck(self):
-        monitor = Monitor(Healthcheck(self.app))
-
-        @self.app.consume_amqp([self.input_queue], monitor)
-        async def handler(message):
-            pass
-
-        await self.app.startup()
-        await self.queue_manager.put(
-            routing_key=self.input_queue,
-            data=self.messages[0]
-        )
-        await asyncio.sleep(1)
-
-        async with aiohttp.ClientSession() as session:
-            timeout = aiohttp.ClientTimeout(total=1)
-            url = f'http://{self.barterdude_host}:8080/healthcheck'
-            async with session.get(url, timeout=timeout) as response:
-                status_code = response.status
-                text = await response.text()
-
-        self.assertEquals(status_code, 200)
-        self.assertEquals(
-            text,
-            '{"message": "Success rate: 1.0 (expected: 0.95)", '
-            '"fail": 0, "success": 1, "status": "ok"}'
-        )
-
-    async def test_obtains_healthcheck_even_with_crashed_hook(self):
-        monitor = Monitor(ErrorHook(), Healthcheck(self.app))
-
-        @self.app.consume_amqp([self.input_queue], monitor)
-        async def handler(message):
-            pass
-
-        await self.app.startup()
-        await self.queue_manager.put(
-            routing_key=self.input_queue,
-            data=self.messages[0]
-        )
-        await asyncio.sleep(1)
-
-        async with aiohttp.ClientSession() as session:
-            timeout = aiohttp.ClientTimeout(total=1)
-            url = f'http://{self.barterdude_host}:8080/healthcheck'
-            async with session.get(url, timeout=timeout) as response:
-                status_code = response.status
-                text = await response.text()
-
-        self.assertEquals(status_code, 200)
-        self.assertEquals(
-            text,
-            '{"message": "Success rate: 1.0 (expected: 0.95)", '
-            '"fail": 0, "success": 1, "status": "ok"}'
-        )
-
-    async def test_obtains_prometheus_metrics(self):
-        labels = {"app_name": "barterdude_consumer"}
-        monitor = Monitor(Prometheus(self.app, labels))
-
-        @self.app.consume_amqp([self.input_queue], monitor)
-        async def handler(message):
-            pass
-
-        await self.app.startup()
-        await self.queue_manager.put(
-            routing_key=self.input_queue,
-            data=self.messages[0]
-        )
-        await asyncio.sleep(1)
-
-        async with aiohttp.ClientSession() as session:
-            timeout = aiohttp.ClientTimeout(total=1)
-            url = f'http://{self.barterdude_host}:8080/metrics'
-            async with session.get(url, timeout=timeout) as response:
-                status_code = response.status
-                text = await response.text()
-
-        self.assertEquals(status_code, 200)
-        self.assertNotEquals(-1, text.find(
-            'barterdude_received_number_before_consume_messages_total'
-            '{app_name="barterdude_consumer"} 1.0'))
-
-    async def test_register_multiple_prometheus_hooks(self):
-        """This test raised the following error:
-           ValueError: Duplicated timeseries in CollectorRegistry"""
-
-        Monitor(
-            Prometheus(self.app, {"app_name": "barterdude1"}, "/metrics1"),
-            Prometheus(self.app, {"app_name": "barterdude2"}, "/metrics2"),
-        )
-
-    async def test_print_logs(self):
-        monitor = Monitor(Logging())
-        error = Exception("raise expected")
-
-        @self.app.consume_amqp([self.input_queue], monitor)
-        async def handler(message):
-            if message.body == self.messages[0]:
-                raise error
-
-        await self.app.startup()
-
-        with self.assertLogs("barterdude") as cm:
-            await self.queue_manager.put(
-                routing_key=self.input_queue,
-                data=self.messages[0]
-            )
-            await asyncio.sleep(1)
-
-        key = self.messages[0]["key"]
-        error_str = repr(error)
-
-        self.assertIn("'message': 'Before consume message'", cm.output[0])
-        self.assertIn(
-            f"'message_body': '{{\"key\": \"{key}\"}}'", cm.output[0]
-        )
-        self.assertIn("'delivery_tag': 1", cm.output[0])
-
-        self.assertIn("'message': 'Failed to consume message'", cm.output[1])
-        self.assertIn(
-            f"'message_body': '{{\"key\": \"{key}\"}}'", cm.output[1]
-        )
-        self.assertIn("'delivery_tag': 1", cm.output[1])
-        self.assertIn(f"'exception': \"{error_str}\"", cm.output[1])
-        self.assertIn("'traceback': [", cm.output[1])
-
     async def test_fails_to_connect_to_rabbitmq(self):
         monitor = Monitor(Logging())
 
